@@ -161,6 +161,22 @@ class VIFHostDevice(VIFBase):
     }
 
 
+@base.VersionedObjectRegistry.register
+class VIFNestedDPDK(VIFBase):
+    # For kuryr-kubernetes nested DPDK interfaces
+
+    VERSION = '1.0'
+
+    fields = {
+        # PCI address of the device.
+        'pci_address': fields.StringField(),
+
+        # Name of the driver the device was previously bound to; it makes
+        # the controller driver agnostic (virtio, sr-iov, etc.)
+        'dev_driver': fields.StringField(),
+    }
+
+
 @base.VersionedObjectRegistry.register
 class VIFPortProfileBase(osv_base.VersionedObject,
                          base.ComparableVersionedObject):
@@ -171,20 +187,32 @@ class VIFPortProfileBase(osv_base.VersionedObject,
 @base.VersionedObjectRegistry.register
 class VIFPortProfileOpenVSwitch(VIFPortProfileBase):
     # Port profile info for OpenVSwitch networks
-
-    VERSION = '1.0'
+    # Version 1.0: Initial release
+    # Version 1.1: Added 'datapath_type'
+    VERSION = '1.1'
 
     fields = {
         'interface_id': fields.UUIDField(),
         'profile_id': fields.StringField(),
+
+        # Datapath type of the bridge
+        'datapath_type': fields.StringField(nullable=True),
     }
 
+    def obj_make_compatible(self, primitive, target_version):
+        super(VIFPortProfileOpenVSwitch, self).obj_make_compatible(
+            primitive, target_version)
+        target_version = versionutils.convert_version_to_tuple(target_version)
+        if target_version < (1, 1) and 'datapath_type' in primitive:
+            del primitive['datapath_type']
+
 
 @base.VersionedObjectRegistry.register
 class VIFPortProfileFPOpenVSwitch(VIFPortProfileOpenVSwitch):
     # Port profile info for OpenVSwitch networks using fastpath
-
-    VERSION = '1.0'
+    # Version 1.0: Initial release
+    # Version 1.1: VIFPortProfileOpenVSwitch updated to 1.1
+    VERSION = '1.1'
 
     fields = {
         # Name of the bridge (managed by fast path) to connect to
@@ -194,6 +222,34 @@ class VIFPortProfileFPOpenVSwitch(VIFPortProfileOpenVSwitch):
         'hybrid_plug': fields.BooleanField(default=False),
     }
 
+    def obj_make_compatible(self, primitive, target_version):
+        target_version = versionutils.convert_version_to_tuple(target_version)
+        if target_version < (1, 1):
+            super(VIFPortProfileFPOpenVSwitch, self).obj_make_compatible(
+                primitive, "1.0")
+
+
+@base.VersionedObjectRegistry.register
+class VIFPortProfileOVSRepresentor(VIFPortProfileOpenVSwitch):
+    # Port profile info for OpenVSwitch networks using a representor
+    # Version 1.0: Initial release
+    # Version 1.1: VIFPortProfileOpenVSwitch updated to 1.1
+    VERSION = '1.1'
+
+    fields = {
+        # Name to set on the representor (if set)
+        'representor_name': fields.StringField(nullable=True),
+
+        # The PCI address of the Virtual Function
+        'representor_address': fields.PCIAddressField(nullable=True),
+    }
+
+    def obj_make_compatible(self, primitive, target_version):
+        target_version = versionutils.convert_version_to_tuple(target_version)
+        if target_version < (1, 1):
+            super(VIFPortProfileOVSRepresentor, self).obj_make_compatible(
+                primitive, "1.0")
+
 
 @base.VersionedObjectRegistry.register
 class VIFPortProfileFPBridge(VIFPortProfileBase):
@@ -242,3 +298,22 @@ class VIFPortProfile8021Qbh(VIFPortProfileBase):
     fields = {
         'profile_id': fields.StringField()
     }
+
+
+@base.VersionedObjectRegistry.register
+class VIFPortProfileK8sDPDK(VIFPortProfileBase):
+    # Port profile info for Kuryr-Kubernetes DPDK ports
+
+    VERSION = '1.0'
+
+    fields = {
+        # Specify whether this vif requires L3 setup.
+        'l3_setup': fields.BooleanField(),
+
+        # String containing URL representing object in Kubernetes API.
+        'selflink': fields.StringField(),
+
+        # String used in Kubernetes v1 API to identifies
+        # the server's internal version of this object.
+        'resourceversion': fields.StringField()
+    }
