@@ -19,6 +19,7 @@
 
 import sys
 
+from os_vif.internal.command import ip as ip_lib
 from os_vif import objects
 from os_vif import plugin
 from oslo_config import cfg
@@ -26,6 +27,8 @@ from oslo_config import cfg
 from vif_plug_ovs import constants
 from vif_plug_ovs import exception
 from vif_plug_ovs import linux_net
+from vif_plug_ovs.ovsdb import api as ovsdb_api
+from vif_plug_ovs.ovsdb import ovsdb_lib
 
 
 class OvsPlugin(plugin.PluginBase):
@@ -53,8 +56,24 @@ class OvsPlugin(plugin.PluginBase):
                    'wait for a response from the database. 0 is to wait '
                    'forever.',
                    deprecated_group="DEFAULT"),
+        cfg.StrOpt('ovsdb_connection',
+                   default=None,
+                   help='The TCP socket connection for communicating with '
+                   'OVS. "None" (default) is for UNIX domain socket '
+                   'connection. If set to "tcp:IP:PORT" eg '
+                   'tcp:127.0.0.1:6640, ovs-vsctl commands will use the '
+                   'tcp:IP:PORT parameter for communicating with OVSDB over '
+                   'a TCP socket.'),
+        cfg.StrOpt('ovsdb_interface',
+                   choices=list(ovsdb_api.interface_map),
+                   default='vsctl',
+                   help='The interface for interacting with the OVSDB'),
     )
 
+    def __init__(self, config):
+        super(OvsPlugin, self).__init__(config)
+        self.ovsdb = ovsdb_lib.BaseOVS(self.config)
+
     @staticmethod
     def gen_port_name(prefix, id):
         return ("%s%s" % (prefix, id))[:OvsPlugin.NIC_NAME_LEN]
@@ -65,25 +84,41 @@ class OvsPlugin(plugin.PluginBase):
                 OvsPlugin.gen_port_name("qvo", vif.id))
 
     def describe(self):
+        pp_ovs = objects.host_info.HostPortProfileInfo(
+            profile_object_name=
+            objects.vif.VIFPortProfileOpenVSwitch.__name__,
+            min_version="1.0",
+            max_version="1.0",
+        )
+        pp_ovs_representor = objects.host_info.HostPortProfileInfo(
+            profile_object_name=
+            objects.vif.VIFPortProfileOVSRepresentor.__name__,
+            min_version="1.0",
+            max_version="1.0",
+        )
         return objects.host_info.HostPluginInfo(
-            plugin_name="ovs",
+            plugin_name=constants.PLUGIN_NAME,
             vif_info=[
                 objects.host_info.HostVIFInfo(
                     vif_object_name=objects.vif.VIFBridge.__name__,
                     min_version="1.0",
-                    max_version="1.0"),
+                    max_version="1.0",
+                    supported_port_profiles=[pp_ovs]),
                 objects.host_info.HostVIFInfo(
                     vif_object_name=objects.vif.VIFOpenVSwitch.__name__,
                     min_version="1.0",
-                    max_version="1.0"),
+                    max_version="1.0",
+                    supported_port_profiles=[pp_ovs]),
                 objects.host_info.HostVIFInfo(
                     vif_object_name=objects.vif.VIFVHostUser.__name__,
                     min_version="1.0",
-                    max_version="1.0"),
+                    max_version="1.0",
+                    supported_port_profiles=[pp_ovs, pp_ovs_representor]),
                 objects.host_info.HostVIFInfo(
                     vif_object_name=objects.vif.VIFHostDevice.__name__,
                     min_version="1.0",
-                    max_version="1.0"),
+                    max_version="1.0",
+                    supported_port_profiles=[pp_ovs, pp_ovs_representor]),
             ])
 
     def _get_mtu(self, vif):
@@ -93,22 +128,29 @@ class OvsPlugin(plugin.PluginBase):
 
     def _create_vif_port(self, vif, vif_name, instance_info, **kwargs):
         mtu = self._get_mtu(vif)
-        linux_net.create_ovs_vif_port(
+        self.ovsdb.create_ovs_vif_port(
             vif.network.bridge,
             vif_name,
             vif.port_profile.interface_id,
             vif.address, instance_info.uuid,
             mtu,
-            timeout=self.config.ovs_vsctl_timeout,
             **kwargs)
 
     def _update_vif_port(self, vif, vif_name):
         mtu = self._get_mtu(vif)
-        linux_net.update_ovs_vif_port(vif_name, mtu)
+        self.ovsdb.update_ovs_vif_port(vif_name, mtu)
+
+    @staticmethod
+    def _get_vif_datapath_type(vif, datapath=constants.OVS_DATAPATH_SYSTEM):
+        profile = vif.port_profile
+        if 'datapath_type' not in profile or not profile.datapath_type:
+            return datapath
+        return profile.datapath_type
 
     def _plug_vhostuser(self, vif, instance_info):
-        linux_net.ensure_ovs_bridge(vif.network.bridge,
-                                    constants.OVS_DATAPATH_NETDEV)
+        self.ovsdb.ensure_ovs_bridge(
+            vif.network.bridge, self._get_vif_datapath_type(
+                vif, datapath=constants.OVS_DATAPATH_NETDEV))
         vif_name = OvsPlugin.gen_port_name(
             constants.OVS_VHOSTUSER_PREFIX, vif.id)
         args = {}
@@ -137,11 +179,11 @@ class OvsPlugin(plugin.PluginBase):
         linux_net.ensure_bridge(vif.bridge_name)
 
         mtu = self._get_mtu(vif)
-        if not linux_net.device_exists(v2_name):
+        if not ip_lib.exists(v2_name):
             linux_net.create_veth_pair(v1_name, v2_name, mtu)
             linux_net.add_bridge_port(vif.bridge_name, v1_name)
-            linux_net.ensure_ovs_bridge(vif.network.bridge,
-                                        constants.OVS_DATAPATH_SYSTEM)
+            self.ovsdb.ensure_ovs_bridge(vif.network.bridge,
+                self._get_vif_datapath_type(vif))
             self._create_vif_port(vif, v2_name, instance_info)
         else:
             linux_net.update_veth_pair(v1_name, v2_name, mtu)
@@ -150,13 +192,13 @@ class OvsPlugin(plugin.PluginBase):
     def _plug_vif_windows(self, vif, instance_info):
         """Create a per-VIF OVS port."""
 
-        if not linux_net.device_exists(vif.id):
-            linux_net.ensure_ovs_bridge(vif.network.bridge,
-                                            constants.OVS_DATAPATH_SYSTEM)
+        if not ip_lib.exists(vif.id):
+            self.ovsdb.ensure_ovs_bridge(vif.network.bridge,
+                                         self._get_vif_datapath_type(vif))
             self._create_vif_port(vif, vif.id, instance_info)
 
     def _plug_vf_passthrough(self, vif, instance_info):
-        linux_net.ensure_ovs_bridge(
+        self.ovsdb.ensure_ovs_bridge(
             vif.network.bridge, constants.OVS_DATAPATH_SYSTEM)
         pci_slot = vif.dev_address
         pf_ifname = linux_net.get_ifname_by_pci_address(
@@ -176,8 +218,8 @@ class OvsPlugin(plugin.PluginBase):
 
         if isinstance(vif, objects.vif.VIFOpenVSwitch):
             if sys.platform != constants.PLATFORM_WIN32:
-                linux_net.ensure_ovs_bridge(vif.network.bridge,
-                                            constants.OVS_DATAPATH_SYSTEM)
+                self.ovsdb.ensure_ovs_bridge(vif.network.bridge,
+                    self._get_vif_datapath_type(vif))
             else:
                 self._plug_vif_windows(vif, instance_info)
         elif isinstance(vif, objects.vif.VIFBridge):
@@ -191,11 +233,10 @@ class OvsPlugin(plugin.PluginBase):
             self._plug_vf_passthrough(vif, instance_info)
 
     def _unplug_vhostuser(self, vif, instance_info):
-        linux_net.delete_ovs_vif_port(vif.network.bridge,
-                                      OvsPlugin.gen_port_name(
-                                          constants.OVS_VHOSTUSER_PREFIX,
-                                          vif.id),
-                                      timeout=self.config.ovs_vsctl_timeout)
+        self.ovsdb.delete_ovs_vif_port(vif.network.bridge,
+            OvsPlugin.gen_port_name(
+                constants.OVS_VHOSTUSER_PREFIX,
+                vif.id))
 
     def _unplug_bridge(self, vif, instance_info):
         """UnPlug using hybrid strategy
@@ -208,14 +249,12 @@ class OvsPlugin(plugin.PluginBase):
 
         linux_net.delete_bridge(vif.bridge_name, v1_name)
 
-        linux_net.delete_ovs_vif_port(vif.network.bridge, v2_name,
-                                      timeout=self.config.ovs_vsctl_timeout)
+        self.ovsdb.delete_ovs_vif_port(vif.network.bridge, v2_name)
 
     def _unplug_vif_windows(self, vif, instance_info):
         """Remove port from OVS."""
-
-        linux_net.delete_ovs_vif_port(vif.network.bridge, vif.id,
-                                      timeout=self.config.ovs_vsctl_timeout)
+        self.ovsdb.delete_ovs_vif_port(vif.network.bridge, vif.id,
+                                       delete_netdev=False)
 
     def _unplug_vf_passthrough(self, vif, instance_info):
         """Remove port from OVS."""
@@ -227,7 +266,7 @@ class OvsPlugin(plugin.PluginBase):
         # The representor interface can't be deleted because it bind the
         # SR-IOV VF, therefore we just need to remove it from the ovs bridge
         # and set the status to down
-        linux_net.delete_ovs_vif_port(
+        self.ovsdb.delete_ovs_vif_port(
             vif.network.bridge, representor, delete_netdev=False)
         linux_net.set_interface_state(representor, 'down')
 
